<?php
/* $Id: danish-iso-8859-1.inc.php 10258 2007-04-07 15:27:37Z lem9 $ */ /* danish - Dansk v 2.162 (based on english 2.159) 2006/09/25 01:23:45 - overstter AlleyKat kan kontaktes p < phpmyadmin (at) phpbb2.dk > */

$charset = 'iso-8859-1';
$text_dir = 'ltr';
$number_thousands_separator = '.';
$number_decimal_separator = ',';
// forkortelser for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits  =  array('B', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');

// MySQL manual sprogdefinition, ikke pkrvet, en bruges hvis
// ikke defineret - da findes endnu ikke
$mysql_4_1_doc_lang = 'en';
$mysql_5_0_doc_lang = 'en';
$mysql_5_1_doc_lang = 'en';

$day_of_week  =  array('sn', 'man', 'tir', 'ons', 'tor', 'fre', 'lr');
$month  =  array('jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'aug', 'sep', 'okt', 'nov', 'dec');
// Se http://www.php.net/manual/en/function.strftime.php
// for at definere variablen herunder
$datefmt = '%d/%m %Y kl. %H:%M:%S';
$timespanfmt = '%s dage, %s timer, %s minutter og %s sekunder';

$strAbortedClients = 'Afbrudt';
$strAccessDenied = 'Adgang Ngtet';
$strAccessDeniedCreateConfig = 'Sandsynlig rsag til dette er at du ikke har oprettet en konfigurationsfil. Du kan bruge %1$sopstningsscriptet%2$s til at oprette en.';
$strAccessDeniedExplanation = 'phpMyAdmin forsgte at forbinde til MySQL-serveren, og serveren afviste forbindelsen. Du br tjekke host, brugernavn og kodeord i config.inc.php og sikre dig at de svarer til den information du har fet af administratoren af MySQL-serveren.';
$strAction = 'Handling';
$strAddAutoIncrement = 'Tilfj AUTO_INCREMENT vrdi';
$strAddClause = 'Tilfj %s';
$strAddConstraints = 'Tilfj begrnsninger';
$strAddDeleteColumn = 'Tilfj/Slet felt-kolonne';
$strAddDeleteRow = 'Tilfj/Slet kriterie-rkke';
$strAddFields = 'Tilfj %s felt(er)';
$strAddHeaderComment = 'Tilfj tilpassede kommentarer i headeren (\\n deler linjer)';
$strAddIntoComments = 'Tilfj til kommentarer';
$strAddNewField = 'Tilfj nyt felt';
$strAddPrivilegesOnDb = 'Tilfj privilegier p flgende database';
$strAddPrivilegesOnTbl = 'Tilfj privileges p flgende tabel';
$strAddSearchConditions = 'Tilfj sgekriterier (kroppen af "WHERE" stningen):';
$strAddToIndex = 'Fj til indeks &nbsp;%s&nbsp;kolonne(r)';
$strAddUserMessage = 'Du har tilfjet en ny bruger.';
$strAddUser = 'Tilfj en ny bruger';
$strAdministration = 'Administration';
$strAffectedRows = 'Berrte rkker:';
$strAfter = 'Efter %s';
$strAfterInsertBack = 'Tilbage til foregende side';
$strAfterInsertNewInsert = 'Indst endnu en ny rkke';
$strAfterInsertNext = 'Redigr nste rkke';
$strAfterInsertSame = 'G tilbage til denne side';
$strAll = 'Alle';
$strAllowInterrupt = 'Tillad afbrydelse af import hvis scriptet er tt p tidsgrnsen. Dette kan vre en god metode til at importere strre filer, men kan knkke transaktioner.';
$strAllTableSameWidth = 'vis alle tabeller med samme bredde?';
$strAlterOrderBy = 'Arrangr tabelrkkeflge efter';
$strAnalyzeTable = 'Analysr tabel';
$strAnd = 'Og';
$strAndThen = 'og derefter';
$strAngularLinks = 'Angulre links';
$strAnIndex = 'Der er tilfjet et indeks til %s';
$strAny = 'Enhver';
$strAnyHost = 'Enhver vrt';
$strAnyUser = 'Enhver bruger';
$strApproximateCount = 'Kan vre anslet. Se FAQ 3.11';
$strAPrimaryKey = 'En primr ngle er blevet tilfjet til %s';
$strArabic = 'Arabisk';
$strArmenian = 'Armensk';
$strAscending = 'Stigende';
$strAtBeginningOfTable = 'I begyndelsen af tabel';
$strAtEndOfTable = 'I slutningen af tabel';
$strAttr = 'Attributter';
$strAutodetect = 'Fastsl automatisk';
$strAutomaticLayout = 'Automatisk layout';

$strBack = 'Tilbage';
$strBaltic = 'Baltisk';
$strBeginCut = 'BEGYND KLIP';
$strBeginRaw = 'BEGYND R';
$strBinary = ' Binrt ';
$strBinaryDoNotEdit = ' Binrt - m ikke ndres ';
$strBinaryLog = 'Binr log';
$strBinLogEventType = 'Hndelsestype';
$strBinLogInfo = 'Information';
$strBinLogName = 'Lognavn';
$strBinLogOriginalPosition = 'Original position';
$strBinLogPosition = 'Position';
$strBinLogServerId = 'Server ID';
$strBookmarkAllUsers = 'Lad alle brugere bruge dette bogmrke';
$strBookmarkCreated = 'Bogmrke %s oprettet';
$strBookmarkDeleted = 'Bogmrket er fjernet.';
$strBookmarkLabel = 'Mrke';
$strBookmarkQuery = 'SQL-foresprgsel med bogmrke';
$strBookmarkReplace = 'Erstat eksisterende bogmrke af samme navn';
$strBookmarkThis = 'Lav bogmrke til denne SQL-foresprgsel';
$strBookmarkView = 'Kun oversigt';
$strBrowseDistinctValues = 'Gennemse bestemte vrdier';
$strBrowseForeignValues = 'Bladre i fremmedvrdier';
$strBrowse = 'Vis';
$strBufferPoolActivity = 'Buffer Pool Aktivitet';
$strBufferPool = 'Buffer Pool';
$strBufferPoolUsage = 'Buffer Pool Forbrug';
$strBufferReadMissesInPercent = 'Read misses i %';
$strBufferReadMisses = 'Read misses';
$strBufferWriteWaitsInPercent = 'Write waits i %';
$strBufferWriteWaits = 'Write waits';
$strBulgarian = 'Bulgarsk';
$strBusyPages = 'Travle sider';
$strBzError = 'phpMyAdmin kunne ikke komprimere dumpet p grund af en delagt Bz2 extension i denne PHP-version. Det anbefales kraftigt at stte <code>$cfg[\'BZipDump\']</code> direktivet i din phpMyAdmin konfigurationsfil til <code>FALSE</code>. Hvis du vil bruge Bz2 komprimeringsfeatures, br du opdatere til en nyere PHP-version. Se PHP bug report %s for detaljer.';
$strBzip = '"bzipped"';

$strCalendar = 'Kalender';
$strCancel = 'Annuller';
$strCanNotLoadExportPlugins = 'Kunne ikke indlse eksportplugins, check venligst din installation!';
$strCanNotLoadImportPlugins = 'Kunne ikke indlse importplugins, check venligst din installation!';
$strCannotLogin = 'Kan ikke logge ind p MySQL-serveren';
$strCantLoad = 'Kan ikke indlse [a@http://php.net/%1$s@Dokumentation][em]%1$s[/em][/a] udvidelsen. Tjek venligst din PHP-konfiguration.';
$strCantLoadRecodeIconv = 'Kan ikke indlse iconv eller omkode ndvendig udvidelse til tegnst-konvertering, konfigurer PHP til at tillade brug af disse udvidelser eller sl tegnst-konvertering fra i phpMyAdmin.';
$strCantRenameIdxToPrimary = 'Kan ikke omdbe indeks til PRIMARY!';
$strCantUseRecodeIconv = 'Kan ikke bruge iconv ejheller libiconv eller recode_string funktionen omend udvidelsen ser ud til at vre indlst. Check din PHP-konfiguration.';
$strCardinality = 'Kardinalitet';
$strCaseInsensitive = 'ingen forskel p store/sm bogstaver';
$strCaseSensitive = 'forskel p store/sm bogstaver';
$strCentralEuropean = 'Centraleuropisk';
$strChange = 'ndre';
$strChangeCopyModeCopy = '... behold den gamle.';
$strChangeCopyModeDeleteAndReload = ' ... slet den gamle fra brugertabellerne og genindls privilegierne efterflgende.';
$strChangeCopyModeJustDelete = ' ... slet den gamle fra brugertabellerne.';
$strChangeCopyMode = 'Opret en bruger med samme privilegier og ...';
$strChangeCopyModeRevoke = ' ... tilbagekald alle aktive privilegier fra den gamle og slet den efterflgende.';
$strChangeCopyUser = 'Ret Login-information / Kopir bruger';
$strChangeDisplay = 'Vlg felt der skal vises';
$strChangePassword = 'ndre kodeord';
$strCharsetOfFile = 'Tegnst for filen:';
$strCharsetsAndCollations = 'Tegnst og kollationer (Collations)';
$strCharsets = 'Tegnst';
$strCharset = 'Tegnst';
$strCheckAll = 'Afmrk alt';
$strCheckOverhead = 'Check tabeller der har overhead';
$strCheckPrivs = 'Check Privilegier';
$strCheckPrivsLong = 'Check privilegier for database &quot;%s&quot;.';
$strCheckTable = 'Tjek tabel';
$strChoosePage = 'Vlg en side der skal redigeres';
$strColComFeat = 'Viser kolonne-kommentarer';
$strCollation = 'Kollation (Collation)';
$strColumnNames = 'Kolonnenavne';
$strColumnPrivileges = 'Kolonne-specifikke privilegier';
$strCommand = 'Kommando';
$strCommentsForTable = 'COMMENTS FOR TABLE (tabel-kommentarer)';
$strComments = 'Kommentarer';
$strCompatibleHashing = 'MySQL&nbsp;4.0 kompatibel';
$strCompleteInserts = 'Komplette inserts';
$strCompression = 'Komprimering';
$strCompressionWillBeDetected = 'Importeret fil-komprimering vil blive automatisk registreret fra: %s';
$strConfigDefaultFileError = 'Kunne ikke indlse standardkonfiguration fra: "%1$s"';
$strConfigFileError = 'phpMyAdmin kunne ikke lse din konfigurationsfil!<br />Dette kan ske hvis PHP finder en parser-fejl i den, eller PHP ikke kan finde filen.<br />Kald konfigurationsfilen direkte fra nedenstende link og ls de(n) PHP-fejlmeddelelse(r) du fr. I de fleste tilflde mangler der et anfrselstegn eller et semikolon et sted.<br />Hvis du fr en blank side, er alt i orden.';
$strConfigureTableCoord = 'Konfigurr venligst koordinaterne for tabel %s';
$strConnectionError = 'Kan ikke forbinde: ugyldige indstillinger.';
$strConnections = 'Forbindelser';
$strConstraintsForDumped = 'Begrnsninger for dumpede tabeller';
$strConstraintsForTable = 'Begrnsninger for tabel';
$strCookiesRequired = 'Herefter skal cookies vre slet til.';
$strCopyDatabaseOK = 'Database %s er blevet kopieret til %s';
$strCopy = 'Kopi';
$strCopyTable = 'Kopier tabel til (database<b>.</b>tabel):';
$strCopyTableOK = 'Tabellen %s er nu kopieret til: %s.';
$strCopyTableSameNames = 'Kan ikke kopiere tabellen til den samme!';
$strCouldNotKill = 'phpMyAdmin kunne ikke drbe trden %s. Den er sandsynligvis allerede lukket.';
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE fr kopiering';
$strCreateIndex = 'Dan et indeks p&nbsp;%s&nbsp;kolonner';
$strCreateIndexTopic = 'Lav et nyt indeks';
$strCreateNewDatabase = 'Opret ny database';
$strCreateNewTable = 'Opret ny tabel i database %s';
$strCreate = 'Opret';
$strCreatePage = 'Opret en ny side';
$strCreatePdfFeat = 'Oprettelse af PDFer';
$strCreateRelation = 'Opret relation';
$strCreateTable  = 'Opret tabel';
$strCreateUserDatabase = 'Database for bruger';
$strCreateUserDatabaseName = 'Opret database med samme navn og tildel alle privilegier';
$strCreateUserDatabaseNone = 'Ingen';
$strCreateUserDatabaseWildcard = 'Tildel alle privilegier til jokertegn-navn (brugernavn_%)';
$strCreationDates = 'Oprettet/Opdateret/Check datoer';
$strCriteria = 'Kriterier';
$strCroatian = 'Kroatisk';
$strCSV = 'CSV (kommasepareret)';
$strCSVImportOptions = 'CSV-indstillinger';
$strCSVOptions = 'CSV-indstillinger';
$strCyrillic = 'Kyrillisk';
$strCzechSlovak = 'Tjekkisk-Slovakisk';
$strCzech = 'Tjekkisk';

$strDanish = 'Dansk';
$strDatabase = 'Database';
$strDatabaseEmpty = 'Databasenavnet er tomt!';
$strDatabaseExportOptions = 'Database eksportindstillinger';
$strDatabaseHasBeenDropped = 'Database %s er slettet.';
$strDatabaseNoTable = 'Denne database indeholder ikke nogen tabel!';
$strDatabases = 'Databaser';
$strDatabasesDropped = '%s databaser er blevet droppet korrekt.';
$strDatabasesStats = 'Databasestatistik';
$strDatabasesStatsDisable = 'Sl Statistikker fra';
$strDatabasesStatsEnable = 'Sl Statistikker til';
$strDatabasesStatsHeavyTraffic = 'Bemrk: Aktivering af databasestatistikkerne hr kan forrsage tung trafik mellem webserveren og MySQL-serveren.';
$strData = 'Data';
$strDataDict = 'Data Dictionary';
$strDataOnly = 'Kun data';
$strDataPages = 'Sider der indeholder data';
$strDBComment = 'Databasekommentar: ';
$strDBCopy = 'Kopir database til';
$strDbIsEmpty = 'Database ser ud til at vre tom!';
$strDbPrivileges = 'Database-specifikke privilegier';
$strDBRename = 'Omdb database til';
$strDbSpecific = 'database-specifik';
$strDefaultEngine = '%s er standard datalageret p denne MySQL-server.';
$strDefault = 'Standardvrdi';
$strDefaultValueHelp = 'For standardvrdier, indtast venligst kun en enkelt vrdi, uden backslash escaping eller quotes, ud fra flgende format: a';
$strDefragment = 'Defragmentr tabel';
$strDelayedInserts = 'Brug forsinkede indsttelser';
$strDeleteAndFlushDescr = 'Dette er den sikreste metode, men genindlsning af privilegierne kan tage noget tid.';
$strDeleteAndFlush = 'Slet brugerne og genindls privilegier bagefter.';
$strDeleted = 'Rkken er slettet!';
$strDeletedRows = 'Slettede rkker:';
$strDeleteNoUsersSelected = 'Ingen brugere valgt til sletning!';
$strDelete = 'Slet';
$strDeleteRelation = 'Slet relation';
$strDeleting = 'Sletter %s';
$strDelimiter = 'Adskiller';
$strDelOld = 'Nuvrende side har referencer til tabeller der ikke lngere eksisterer. Vil du slette disse referencer?';
$strDescending = 'Faldende';
$strDescription = 'Beskrivelse';
$strDesigner = 'Designer';
$strDesignerHelpDisplayField = 'Visningsfeltet er vist som pink. For at stte/fjerne et felt som visningsfelt, klik p "Vlg felt der skal vises" ikonet, og klik derefter p det pgldende feltnavn.';
$strDictionary = 'ordbog';
$strDirectLinks = 'Direkte links';
$strDirtyPages = 'Beskidte sider';
$strDisabled = 'Slet fra';
$strDisableForeignChecks = 'Sl fremmedngle-checks fra';
$strDisplayFeat = 'Vis muligheder';
$strDisplayOrder = 'Rkkeflge af visning:';
$strDisplayPDF = 'Vis PDF-skematik';
$strDoAQuery = 'Kr en foresprgsel p felter (jokertegn: "%")';
$strDocSQL = 'DocSQL';
$strDocSQLOptions = 'DocSQL indstillinger';
$strDocu = 'Dokumentation';
$strDoYouReally = 'Er du sikker p at du vil ';
$strDropDatabaseStrongWarning = 'Du er ved at DESTRUERE en komplet database!';
$strDrop = 'Slet';
$strDropUsersDb = 'Drop databaser der har samme navne som brugernes.';
$strDumpingData = 'Data dump for tabellen';
$strDumpSaved = 'Dump er blevet gemt i filen %s.';
$strDumpXRows = 'Dump %s rkker startende med rkke %s.';
$strDynamic = 'dynamisk';

$strEditPDFPages = 'Redigr PDF-sider';
$strEditPrivileges = 'Ret privilegier';
$strEdit = 'Ret';
$strEffective = 'Effektiv';
$strEmptyResultSet = 'MySQL returnerede ingen data (fx ingen rkker).';
$strEmpty = 'Tm';
$strEnabled = 'Slet til';
$strEncloseInTransaction = 'Inkludr eksport i en transaktion';
$strEndCut = 'SLUT KLIP';
$strEndRaw = 'SLUT R';
$strEnd = 'Slut';
$strEngineAvailable = '%s er tilgngelig p denne MySQL-server.';
$strEngineDisabled = '%s er slet fra p denne MySQL-server.';
$strEngines = 'Lagre';
$strEngineUnsupported = 'Denne MySQL-server understtter ikke %s datalager.';
$strEnglish = 'Engelsk';
$strEnglishPrivileges = ' NB: Navne p MySQL privilegier er p engelsk ';
$strError = 'Fejl';
$strErrorInZipFile = 'Fejl i ZIP arkiv:';
$strErrorRelationAdded = 'Fejl: Relation ikke tilfjet.';
$strErrorRelationExists = 'Fejl: Relation findes allerede.';
$strErrorSaveTable = 'Fejl ved lagring af koordinater for Designer.';
$strErrorRenamingTable = 'Fejl ved omdbning af tabel  %1$s til %2$s';
$strEscapeWildcards = 'Jokertegn _ og % skal vre escaped med en \ foran for at bruge dem bogstaveligt';
$strEsperanto = 'Esperanto';
$strEstonian = 'Estisk';
$strExcelEdition = 'Excel-udgave';
$strExcelOptions = 'Excel-indstillinger';
$strExecuteBookmarked = 'Udfr foresprgsel iflg. bogmrke';
$strExplain = 'Forklar SQL';
$strExport = 'Eksport';
$strExportImportToScale = 'Eksporter/Importer til skala';
$strExportMustBeFile = 'Valgte eksporttype skal gemmes som fil!';
$strExtendedInserts = 'Udvidede inserts';
$strExtra = 'Ekstra';

$strFailedAttempts = 'Mislykkede forsg';
$strField = 'Feltnavn';
$strFieldHasBeenDropped = 'Felt %s er slettet';
$strFieldsEmpty = ' Felttallet har ingen vrdi! ';
$strFieldsEnclosedBy = 'Felter indrammet med';
$strFieldsEscapedBy = 'Felter escaped med';
$strFields = 'Felter';
$strFieldsTerminatedBy = 'Felter afsluttet med';
$strFileAlreadyExists = 'Filen %s findes allerede p serveren, lav filnavnet om eller tillad at der overskrives.';
$strFileCouldNotBeRead = 'Filen kunne ikke lses';
$strFileNameTemplateDescriptionDatabase = 'databasenavn';
$strFileNameTemplateDescription = 'Denne vrdi fortolkes via %1$sstrftime%2$s, s du kan bruge tidsformatterede strenge. Ydermere vil flgende transformationer foreg: %3$s. Anden tekst vil blive bevaret som det er.';
$strFileNameTemplateDescriptionServer = 'servernavn';
$strFileNameTemplateDescriptionTable = 'tabelnavn';
$strFileNameTemplateRemember = 'husk skabelonen';
$strFileNameTemplate = 'Skabelon for filnavn';
$strFileToImport = 'Fil til import';
$strFixed = 'ordnet';
$strFlushPrivilegesNote = 'Bemrk: phpMyAdmin henter brugernes privilegier direkte fra MySQLs privilegietabeller. Indholdet af disse tabeller kan vre forskelligt fra privilegierne serveren i jeblikket bruger hvis der er lavet manuelle ndringer i den. Hvis dette er tilfldet, br du %sgenindlse privilegierne%s fr du fortstter.';
$strFlushQueryCache = 'Flush foresprgsel-mellemlager (query cache)';
$strFlushTable = 'Flush tabellen ("FLUSH")';
$strFlushTables = 'Flush (luk) alle tabeller';
$strFontSize = 'Skriftstrrelse';
$strForeignKeyError = 'Fejl ved oprettelse af fremmedngle (check datatyper)';
$strFormat = 'Format';
$strFormEmpty = 'Ingen vrdi i formularen !';
$strFreePages = 'Frie sider';
$strFullText = 'Komplette tekster';
$strFunction = 'Funktion';
$strFunctions = 'Funktioner';

$strGenBy = 'Genereret af';
$strGeneralRelationFeat = 'Generelle relationsmuligheder';
$strGenerate = 'Generr';
$strGeneratePassword = 'Generr Kodeord';
$strGenTime = 'Genereringstid';
$strGeorgian = 'Georgisk';
$strGerman = 'Tysk';
$strGlobal = 'global';
$strGlobalPrivileges = 'Globale privilegier';
$strGlobalValue = 'Global vrdi';
$strGo = 'Udfr';
$strGrantOption = 'Tildel';
$strGreek = 'Grsk';
$strGzip = '"gzipped"';

$strHandler = 'Handler';
$strHasBeenAltered = 'er ndret.';
$strHasBeenCreated = 'er oprettet.';
$strHaveToShow = 'Du skal vlge mindst en kolonne der skal vises';
$strHebrew = 'Hebrisk';
$strHelp = 'Hjlp';
$strHexForBinary = 'Brug hexadecimal til binre felter';
$strHide         = 'Skjul';
$strHideShowAll = 'Skjul/Vis alle';
$strHideShowNoRelation = 'Skjul/Vis tabeller uden relation';
$strHome = 'Hjem';
$strHomepageOfficial = 'Officiel phpMyAdmin hjemmeside ';
$strHostEmpty = 'Der er intet vrtsnavn!';
$strHost = 'Vrt';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Microsoft Excel 2000 eksportindstillinger';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Microsoft Word 2000 eksportindstillinger';
$strHungarian = 'Ungarsk';

$strIcelandic = 'Islandsk';
$strId = 'ID';
$strIdxFulltext = 'Fuldtekst';
$strIEUnsupported = 'Internet Explorer understtter ikke denne funktion.';
$strIgnoreDuplicates = 'Ignorr gentagne rkker';
$strIgnore = 'Ignorer';
$strIgnoreInserts = 'Brug ignorr inserts';
$strImportExportCoords = 'Importer/Eksporter koordinater for PDF-opstilling';
$strImportFiles = 'Importr filer';
$strImportFormat = 'Format p importeret fil';
$strImport = 'Import';
$strImportSuccessfullyFinished = 'Importen er korrekt gennemfrt, %d foresprgsler udfrt.';
$strIndexes = 'Indeks';
$strIndexHasBeenDropped = 'Indeks %s er blevet slettet';
$strIndex = 'Indeks';
$strIndexName = 'Indeksnavn&nbsp;:';
$strIndexType = 'Indekstype&nbsp;:';
$strIndexWarningMultiple = 'Mere end en %s ngle blev skabt for kolonne `%s`';
$strIndexWarningPrimary = 'PRIMARY og INDEX ngler burde ikke begge vre sat for kolonne `%s`';
$strIndexWarningTable = 'Problemer med indeksene p tabel `%s`';
$strIndexWarningUnique = 'UNIQUE og INDEX ngler burde ikke begge vre sat for kolonne `%s`';
$strInnoDBAutoextendIncrement = 'Autoextend forgelse';
$strInnoDBAutoextendIncrementDesc = ' Strrelsen p den udvidelse der vil forekomme, nr pladsen i en autoudvidende tabel udvides fordi den lber fuld.';
$strInnoDBBufferPoolSize = 'Buffer pool strrelse';
$strInnoDBBufferPoolSizeDesc = 'Strrelse p memorybufferen InnoDB bruger til at mellemlagre data og indeks p dens tabeller.';
$strInnoDBDataFilePath = 'Datafiler';
$strInnoDBDataHomeDir = 'Data hovedmappe';
$strInnoDBDataHomeDirDesc = 'Den flles del af stien til mappen med alle InnoDB datafiler.';
$strInnoDBPages = 'sider';
$strInnoDBRelationAdded = 'InnoDB-relation tilfjet';
$strInnodbStat = 'InnoDB status';
$strInsecureMySQL = 'Din konfigurationsfil indeholder indstillinger (root og intet kodeord) som svarer til en standard MySQL-priviligeret brugerkonto. Din MySQL server krer med denne standardindstilling, <u>er ben for indtrngen</u>, og du opfordres strkt til at gre noget ved dette sikkerhedshul.';
$strInsertAsNewRow = 'Indst som ny rkke';
$strInsertedRowId = 'Indsat rkke-id:';
$strInsertedRows = 'Indsatte rkker:';
$strInsert = 'Indst';
$strInternalNotNecessary = '* En intern relation er ikke ndvendig nr den ogs eksisterer i InnoDB.';
$strInternalRelationAdded = 'Intern relation tilfjet';
$strInternalRelations = 'Interne relationer';
$strInUse = 'i brug';
$strInvalidAuthMethod = 'Ugyldig autorisationsmetode sat i konfiguration:';
$strInvalidColumnCount = 'Kolonneantal skal vre strre end nul.';
$strInvalidColumn = 'Ugyldig kolonne (%s) angivet!';
$strInvalidCSVFieldCount = 'Ugyldigt feltantal i CSV-input p linie %d.';
$strInvalidCSVFormat = 'Ugyldigt format for CSV-input p linie %d.';
$strInvalidCSVParameter = 'Ugyldigt parameter for CSV-import: %s';
$strInvalidDatabase = 'Ugyldig database';
$strInvalidFieldAddCount = 'Du skal tilfje mindst t felt.';
$strInvalidFieldCount = 'Tabellen skal indeholde mindst t felt.';
$strInvalidLDIImport = 'Denne plugin understtter ikke komprimeret import!';
$strInvalidRowNumber = '%d er ikke et gyldigt rkkenummer.';
$strInvalidServerHostname = 'Ugyldigt hostnavn for server %1$s. Gennemg venligst din konfiguration.';
$strInvalidServerIndex = 'Ugyldigt server indeks: "%s"';
$strInvalidTableName = 'Ugyldigt tabelnavn';

$strJapanese = 'Japansk';
$strJoins = 'Joins';
$strJumpToDB = 'Hop til database &quot;%s&quot;.';
$strJustDelete = 'Bare slet brugerne fra privilegietabellerne.';
$strJustDeleteDescr = 'De &quot;slettede&quot; brugere kan stadig tilg serveren som de plejer indtil privilegierne genindlses.';

$strKeepPass = 'Kodeord m ikke ndres';
$strKeyCache = 'Nglemellemlager (key cache)';
$strKeyname = 'Nglenavn';
$strKill = 'Drb (Kill)';
$strKnownExternalBug = 'Funktionaliteten af %s er pvirket af en kendt fejl, se %s';
$strKorean = 'Koreansk';

$strLandscape = 'Liggende';
$strLanguageFileNotFound = 'Sprogfil \"%1$s\" ikke fundet.';
$strLanguage = 'Sprog';
$strLanguageUnknown = 'Ukendt sprog: %1$s.';
$strLatchedPages = 'Eksklusivt lste (latched) sider';
$strLatexCaption = 'Tabeloverskrift';
$strLatexContent = 'Indhold af tabel __TABLE__';
$strLatexContinuedCaption = 'Fortsat tabeloverskrift';
$strLatexContinued = '(fortsttes)';
$strLatexIncludeCaption = 'Inkluder tabeloverskrift';
$strLatexLabel = 'Mrke ngle';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX indstillinger';
$strLatexStructure = 'Struktur for tabel __TABLE__';
$strLatvian = 'Lettisk';
$strLDI = 'CSV vha. LOAD DATA';
$strLDIImportOptions = 'Indstillinger for CSV import via LOAD DATA';
$strLDILocal = 'Brug LOCAL ngleord';
$strLengthSet = 'Lngde/Vrdi*';
$strLimitNumRows = 'poster pr. side';
$strLinesTerminatedBy = 'Linjer afsluttet med';
$strLinkNotFound = 'Link ikke fundet';
$strLinksTo = 'Linker til';
$strLithuanian = 'Litauisk';
$strLocalhost = 'Lokal';
$strLocationTextfile = 'Tekstfilens placering';
$strLoginInformation = 'Login-information';
$strLogin = 'Login';
$strLogout = 'Log af';
$strLogPassword = 'Kodeord:';
$strLogServer = 'Server';
$strLogUsername = 'Brugernavn:';
$strLongOperation = 'Denne operation kan tage lang tid. Fortst alligevel?';

$strMaxConnects = 'maks. samtidige forbindelser';
$strMaximalQueryLength = 'Maksimal lngde p oprettet foresprgsel';
$strMaximumSize = 'Maksimum strrelse: %s%s';
$strMbExtensionMissing = 'PHP-udvidelsen mbstring blev ikke fundet og du ser ud til at bruge et multibyte tegnst. Uden mbstring-udvidelsen er phpMyAdmin ude af stand til at opdele strenge korrekt og dette kan forrsage uventede resultater';
$strMbOverloadWarning = 'Du har mbstring.func_overload slet til i din PHP-konfiguration. Denne indstilling er ikke kompatibel med phpMyAdmin og kan forrsage delggelse af nogle data!';
$strMIME_available_mime = 'Tilgngelige MIME-typer';
$strMIME_available_transform = 'Tilgngelige transformationer';
$strMIME_description = 'Beskrivelse';
$strMIME_MIMEtype = 'MIME-type';
$strMIME_nodescription = 'Der er ingen beskrivelse af denne transformation.<br />Sprg venligst forfatteren, hvad %s gr.';
$strMIME_transformation = 'Browser transformation';
$strMIME_transformation_note = 'For en liste over mulige transformationsindstillinger og deres MIME-type transformationer, klik p %stransformationsbeskrivelser%s';
$strMIME_transformation_options_note = 'Indtast vrdier for transformationsindstillinger ud fra flgende format: \'a\', 100, b,\'c\'...<br />Skulle du f brug for at indstte en backslash ("\") eller en apostrof ("\'") i vrdierne, backslash det (for eksempel \'\\\\xyz\' eller \'a\\\'b\').';
$strMIME_transformation_options = 'Transformationsindstillinger';
$strMIMETypesForTable = 'MIME TYPES FOR TABLE (MIME-typer for tabellen)';
$strMIME_without = 'MIME-typer skrevet med kursiv har ikke en separat transformationsfunktion';
$strModifications = 'Rettelserne er gemt!';
$strModifyIndexTopic = 'ndring af et indeks';
$strModify = 'Ret';
$strMoveMenu = 'Flyt Menu';
$strMoveTable = 'Flyt tabel til (database<b>.</b>tabel):';
$strMoveTableOK = 'Tabel %s er flyttet til %s.';
$strMoveTableSameNames = 'Kan ikke flytte tabellen til den samme!';
$strMultilingual = 'flersproget';
$strMyISAMDataPointerSize = 'Data pointer strrelse';
$strMyISAMDataPointerSizeDesc = 'Standard pointerstrrelse i bytes, til brug ved CREATE TABLE for MyISAM tabeller nr der ikke er specificeret nogen MAX_ROWS indstilling.';
$strMyISAMMaxExtraSortFileSizeDesc = 'Hvis den midlertidige fil der bruges til hurtig MyISAM indeks-oprettelse ville vre strre end ved brug af key cache med strrelsen angivet her, foretrk key cache-metoden.';
$strMyISAMMaxExtraSortFileSize = 'Maksimal strrelse for midlertidige filer ved oprettelse af indeks';
$strMyISAMMaxSortFileSizeDesc = 'Maksimal strrelse for den midlertidige fil MySQL har lov til at bruge under genetablering af et MyISAM indeks (under REPAIR TABLE, ALTER TABLE, eller LOAD DATA INFILE).';
$strMyISAMMaxSortFileSize = 'Maksimal strrelse for midlertidige sorteringsfiler';
$strMyISAMRecoverOptions = 'Automatisk genopretnings-modus';
$strMyISAMRecoverOptionsDesc = 'Modus for automatisk genetablering af crashede MyISAM tabeller, som sat via --myisam-recover server opstartsindstillingen.';
$strMyISAMRepairThreadsDesc = 'Hvis denne vrdi er strre end 1, oprettes MyISAM tabel-indeks parallelt (hvert indeks i dets egen trd) under Reparation ved sortering-processen.';
$strMyISAMRepairThreads = 'Reparr trde';
$strMyISAMSortBufferSizeDesc = 'Bufferen der allokeres ved sortering af MyISAM indeks under en REPAIR TABLE eller nr indeks oprettes med CREATE INDEX eller ALTER TABLE.';
$strMyISAMSortBufferSize = 'Sorterings-bufferstrrelse';
$strMySQLCharset = 'MySQL Tegnst';
$strMysqlClientVersion = 'MySQL klientversion';
$strMySQLConnectionCollation = 'MySQL forbindelses-sammenkring';
$strMySQLSaid = 'MySQL returnerede: ';
$strMySQLShowProcess = 'Vis trde';
$strMySQLShowStatus = 'Vis MySQL runtime-information';
$strMySQLShowVars = 'Vis MySQL systemvariabler';

$strName = 'Navn';
$strNext = 'Nste';
$strNoActivity = 'Ingen aktivitet i de seneste %s sekunder eller mere, log venligst ind igen';
$strNoDatabases = 'Ingen databaser';
$strNoDatabasesSelected = 'Ingen databaser valgt.';
$strNoDataReceived = 'Der blev ikke modtaget nogen data til import. Enten blev der ikke indsendt et filnavn, eller filstrrelsen kan have overskredet maksimalstrrelsen tilladt af din PHP-konfiguration. Se FAQ 1.16.';
$strNoDescription = 'ingen beskrivelse';
$strNoDetailsForEngine = 'Der er ingen detaljerede statusinformationer tilgngelige for dette datalager.';
$strNoDropDatabases = '"DROP DATABASE" erklringer kan ikke bruges.';
$strNoExplain = 'Spring over Forklar SQL';
$strNoFilesFoundInZip = 'Ingen filer fundet i ZIP arkivet!';
$strNoFrames = 'phpMyAdmin er mere brugervenlig med en browser, der kan klare <b>frames</b>.';
$strNoIndex = 'Intet indeks defineret!';
$strNoIndexPartsDefined = 'Ingen dele af indeks er defineret!';
$strNoModification = 'Ingen ndring';
$strNone = 'Intet';
$strNo = 'Nej';
$strNoOptions = 'Dette format har ingen indstillinger';
$strNoPassword = 'Intet kodeord';
$strNoPermission = 'Webserveren har ikke tilladelse til at gemme filen %s.';
$strNoPhp = 'uden PHP-kode';
$strNoPrivileges = 'Ingen privilegier';
$strNoRights = 'Du har ikke tilstrkkelige rettigheder til at vre her!';
$strNoRowsSelected = 'Ingen rkker valgt';
$strNoSpace = 'Utilstrkkeligt plads til at gemme filen %s.';
$strNoTablesFound = 'Ingen tabeller fundet i databasen.';
$strNoThemeSupport = 'Ingen tema/layout-understttelse, tjek venligst din konfiguration og/eller dine temaer i mappen %s.';
$strNotNumber = 'Dette er ikke et tal!';
$strNotOK = 'ikke OK';
$strNotSet = 'Tabel <b>%s</b> findes ikke eller er ikke sat i %s';
$strNoUsersFound = 'Ingen bruger(e) fundet.';
$strNoValidateSQL = 'Spring over Validr SQL';
$strNull = 'Nulvrdi';
$strNumberOfFields = 'Antal felter';
$strNumberOfTables = 'Antal tabeller';
$strNumSearchResultsInTable = '%s hit(s) i tabel <i>%s</i>';
$strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> hit(s)';
$strNumTables = 'Tabeller';

$strOK = 'OK';
$strOpenDocumentSpreadsheet = 'Open Document regneark';
$strOpenDocumentSpreadsheetOptions = 'Open Document regnearksindstillinger';
$strOpenDocumentText = 'Open Document tekst';
$strOpenDocumentTextOptions = 'Open Document tekstindstillinger';
$strOpenNewWindow = 'bn nyt phpMyAdmin vindue';
$strOperations = 'Operationer';
$strOperator = 'Operatr';
$strOptimizeTable = 'Optimer tabel';
$strOr = 'Eller';
$strOverhead = 'Overhead';
$strOverwriteExisting = 'Overskriv eksisterende fil(er)';

$strPageNumber = 'Side nummer:';
$strPagesToBeFlushed = 'Sider der str til at blive tmt';
$strPaperSize = 'Papirstrrelse';
$strPartialImport = 'Delvis import';
$strPartialText = 'Delvise tekster';
$strPasswordChanged = 'Kodeordet for %s blev korrekt udskiftet.';
$strPasswordEmpty = 'Der er ikke angivet noget kodeord!';
$strPasswordHashing = 'Kodeord Hashing';
$strPassword = 'Kodeord';
$strPasswordNotSame = 'De to kodeord er ikke ens!';
$strPdfDbSchema = 'Skematik for databasen "%s" - Side %s';
$strPdfInvalidTblName = 'Tabellen "%s" findes ikke!';
$strPdfNoTables = 'Ingen tabeller';
$strPDFOptions = 'PDF-indstillinger';
$strPDF = 'PDF';
$strPDFReportExplanation = '(Genererer en rapport indeholdende dataene fra en enkelt tabel)';
$strPDFReportTitle = 'Rapporttitel';
$strPerHour = 'pr. time';
$strPerMinute = 'pr. minut';
$strPerSecond = 'pr. sekund';
$strPersian = 'Persisk';
$strPhoneBook = 'telefonbog';
$strPHP40203 = 'Du bruger PHP 4.2.3, som har en alvorlig fejl med multi-byte strenge (mbstring). Se PHP bug report 19404. Denne version af PHP kan ikke anbefales at bruge med phpMyAdmin.';
$strPhp = 'Fremstil PHP-kode';
$strPHPVersion = 'PHP-version';
$strPleaseSelectPrimaryOrUniqueKey = 'Vlg venligst den primre ngle eller en unik ngle';
$strPmaDocumentation = 'phpMyAdmin dokumentation';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> direktivet SKAL vre sat i din konfigurationsfil!';
$strPmaWiki = 'phpMyAdmin wiki';
$strPolish = 'Polsk';
$strPortrait = 'Stende';
$strPos1 = 'Start';
$strPrevious = 'Forrige';
$strPrimaryKeyHasBeenDropped = 'Primrnglen er slettet';
$strPrimaryKeyName = 'Navnet p primrnglen skal vre... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>skal</b> vre navnet p og <b>kun p</b> en primr ngle!)';
$strPrimary = 'Primr';
$strPrint = 'Print';
$strPrintViewFull = 'Udskrift-visning (med fulde tekster)';
$strPrintView = 'Vis (udskriftvenlig)';
$strPrivDescAllPrivileges = 'Inkluderer alle privilegier pnr GRANT.';
$strPrivDescAlterRoutine = 'Tillader ndring og sletning af gemte rutiner.';
$strPrivDescAlter = 'Tillader ndring af strukturen p eksisterende tabeller.';
$strPrivDescCreateDb = 'Tillader oprettelse af nye databaser og tabeller.';
$strPrivDescCreateRoutine = 'Tillader oprettelse af gemte rutiner.';
$strPrivDescCreateTbl = 'Tillader oprettelse af nye tabeller.';
$strPrivDescCreateTmpTable = 'Tillader oprettelse af midlertidige tabeller.';
$strPrivDescCreateUser = 'Tillader oprettelse, sletning og omdbning af brugerkonti.';
$strPrivDescCreateView = 'Tillader oprettelse af nye Allows creating new views.';
$strPrivDescDelete = 'Tillader sletning af data.';
$strPrivDescDropDb = 'Tillader at droppe databaser og tabeller.';
$strPrivDescDropTbl = 'Tillader at droppe tabeller.';
$strPrivDescExecute5 = 'Tillader udfrelse af gemte rutiner.';
$strPrivDescExecute = 'Tillader krsel af gemte procedurer; Har ingen effekt i denne MySQL-version.';
$strPrivDescFile = 'Tillader import af data fra og eksport af data til filer.';
$strPrivDescGrant = 'Tillader oprettelse af brugere og privilegier uden at genindlse privilegie-tabellerne.';
$strPrivDescIndex = 'Tillader at skabe og droppe indeks.';
$strPrivDescInsert = 'Tillader indsttelse og erstatning af data.';
$strPrivDescLockTables = 'Tillader lsning af tabeller for nuvrende trd.';
$strPrivDescMaxConnections = 'Begrnser antallet af nye forbindelser brugeren m bne pr. time.';
$strPrivDescMaxQuestions = 'Begrnser antallet af foresprgsler brugeren m sende til serveren pr. time.';
$strPrivDescMaxUpdates = 'Begrnser antallet af kommandoer som ndrer enhver tabel eller database brugeren m udfre pr. time.';
$strPrivDescMaxUserConnections = 'Begrnser antallet af samtidige forbindelser brugere m have.';
$strPrivDescProcess3 = 'Tillader at drbe andre brugeres processer.';
$strPrivDescProcess4 = 'Tillader at se komplette foresprgsler i proceslisten.';
$strPrivDescReferences = 'Har ingen effekt i denne MySQL version.';
$strPrivDescReload = 'Tillader genindlsning af serverindstillinger og tmning af caches.';
$strPrivDescReplClient = 'Giver brugeren rettigheder til at sprge hvor Slaves / Masters er.';
$strPrivDescReplSlave = 'Ndvendigt for replikationsslaverne.';
$strPrivDescSelect = 'Tillader lsning af data.';
$strPrivDescShowDb = 'Giver adgang til den fuldstndige liste over databaser.';
$strPrivDescShowView = 'Tillader udfrelse af SHOW CREATE VIEW foresprgsler.';
$strPrivDescShutdown = 'Tillader nedlukning af serveren.';
$strPrivDescSuper = 'Tillader forbindelse, selv hvis maksimalt antal forbindelser er net; Ndvendigt for de fleste administrative operationer som indstilling af globale variabler eller for at drbe andre brugeres trde.';
$strPrivDescUpdate = 'Tillader ndring af data.';
$strPrivDescUsage = 'Ingen privilegier.';
$strPrivileges = 'Privilegier';
$strPrivilegesReloaded = 'Privilegierne blev korrekt genindlst.';
$strProcedures = 'Procedurer';
$strProcesses = 'Processer';
$strProcesslist = 'Procesliste';
$strProtocolVersion = 'Protokolversion';
$strPutColNames = 'Indst feltnavne i frste rkke';

$strQBEDel = 'Del (Slet)';
$strQBE = 'Foresp. via eks.';
$strQBEIns = 'Ins (Indst)';
$strQueryCache = 'Foresprgsel-mellemlager';
$strQueryFrame = 'Foresp. vindue';
$strQueryOnDb = 'SQL-foresprgsel til database <b>%s</b>:';
$strQueryResultsOperations = 'Foresprgselsresultat operationer';
$strQuerySQLHistory = 'SQL-historik';
$strQueryStatistics = '<b>Foresprgselsstatistikker</b>: Siden opstarten er der blevet sendt %s foresprgsler til serveren.';
$strQueryTime = 'Foreprgsel tog %01.4f sek';
$strQueryType = 'Foresprgselstype';
$strQueryWindowLock = 'Overskriv ikke denne foresprgsel fra udenfor vinduet';

$strReadRequests = 'Read-anmodninger';
$strReceived = 'Modtaget';
$strRecommended = 'anbefalet';
$strRecords = 'Poster';
$strReferentialIntegrity = 'Check reference-integriteten';
$strRefresh = 'Opdatr';
$strRelationalSchema = 'Relationel skematik';
$strRelationDeleted = 'Relation slettet';
$strRelationNotWorking = 'De ekstra features for at arbejde med linkede tabeller er deaktiveret. For at se hvorfor, klik %sher%s.';
$strRelationsForTable = 'RELATIONS FOR TABLE (Relationer for tabellen)';
$strRelations = 'Relationer';
$strRelationView = 'Se Relationer';
$strReloadingThePrivileges = 'Genindls privilegierne';
$strReloadPrivileges = 'Genindls privilegier';
$strReload = 'Genindls';
$strRemoveSelectedUsers = 'Fjern valgte brugere';
$strRenameDatabaseOK = 'Database %s er blevet omdbt til %s';
$strRenameTableOK = 'Tabellen %s er nu omdbt til %s';
$strRenameTable = 'Omdb tabel til';
$strRepairTable = 'Reparer tabel';
$strReplaceNULLBy = 'Erstat NULL med';
$strReplaceTable = 'Erstat data i tabellen med filens data';
$strReplication = 'Replikering';
$strReset = 'Nulstil';
$strResourceLimits = 'Ressourcebegrnsninger';
$strReType = 'Skriv igen';
$strRevokeAndDeleteDescr = 'Bruger(e) vil fortsat have USAGE-privilegiet indtil privilegierne genindlses.';
$strRevokeAndDelete = 'Tilbagekald alle aktive privilegier fra brugerne og slet dem efterflgende.';
$strRevokeMessage = 'Du har tilbagekaldt privilegierne for %s';
$strRevoke = 'Tilbagekald';
$strRomanian = 'Rumnsk';
$strRowLength = 'Rkkelngde';
$strRowsFrom = 'rkker startende fra post #';
$strRowSize = ' Rkkestrrelse ';
$strRowsModeFlippedHorizontal = 'horisontalt (roterede overskrifter)';
$strRowsModeHorizontal = 'vandret';
$strRowsModeOptions = '%s og gentag overskrifter efter %s celler';
$strRowsModeVertical = 'lodret';
$strRows = 'Rkker';
$strRowsStatistic = 'Rkke-statistik';
$strRunning = 'krer p %s';
$strRunQuery = 'Send foresprgsel';
$strRunSQLQuery = 'Kr SQL-forsprgsel(er) p database %s';
$strRunSQLQueryOnServer = 'Kr SQL-foresprgsel/foresprgsler p server %s';
$strRussian = 'Russisk';

$strSave = 'Gem';
$strSavePosition = 'Gem position';
$strSaveOnServer = 'Gem p serveren i mappen %s ';
$strScaleFactorSmall = 'Skaleringsfaktoren er for lille til at tilpasse skematikken til en side';
$strSearchFormTitle = 'Sg i databasen';
$strSearchInTables = 'Indeni tabel(ler):';
$strSearchNeedle = 'Ord eller vrdi(er) (jokertegn: "%"):';
$strSearchOption1 = 'mindst et af ordene';
$strSearchOption2 = 'alle ordene';
$strSearchOption3 = 'den njagtige stning';
$strSearchOption4 = 'som regulrt udtryk';
$strSearchResultsFor = 'Sgeresultater for "<i>%s</i>" %s:';
$strSearch = 'Sg';
$strSearchType = 'Find:';
$strSecretRequired = 'Konfigurationsfilen skal nu bruge et hemmeligt kodeord (blowfish_secret).';
$strSelectADb = 'Vlg en database';
$strSelectAll = 'Vlg alle';
$strSelectBinaryLog = 'Vlg binrlog til gennemsyn';
$strSelectFields = 'Vlg mindst eet felt:';
$strSelectForeignKey = 'Vlg fremmedngle';
$strSelectNumRows = 'i foresprgsel';
$strSelectReferencedKey = 'Vlg refereret ngle';
$strSelectTables = 'Vlg Tabeller';
$strSend = 'Send (download)';
$strSent = 'Sendt';
$strServerChoice = 'Server valg';
$strServerNotResponding = 'Serveren svarer ikke';
$strServer = 'Server';
$strServers = 'Servere';
$strServerStatusDelayedInserts = 'Forsinkede inserts';
$strServerStatus = 'Runtime-information';
$strServerStatusUptime = 'Denne MySQL-server har krt i %s. Den startede op den %s.';
$strServerTabVariables = 'Variabler';
$strServerTrafficNotes = '<b>Servertrafik</b>: Disse tabeller viser netvrkstrafik-statistikkerne for denne MySQL-server siden dens opstart.';
$strServerVars = 'Server-variabler og indstillinger';
$strServerVersion = 'Serverversion';
$strSessionValue = 'Sessionsvrdi';
$strSetEnumVal = 'Hvis et felt er af typen "enum" eller "set", skal vrdierne angives p formen: \'a\',\'b\',\'c\'...<br />Skulle du f brug for en backslash ("\") eller et enkelt anfrselstegn ("\'") blandt disse vrdier, s tilfj en ekstra backslash (fx \'\\\\xyz\' eller \'a\\\'b\').';
$strShowAll = 'Vis alle';
$strShowColor = 'Vis farve';
$strShowDatadictAs = 'Data Dictionary-format';
$strShowFullQueries = 'Vis fuldstndige foresprgsler';
$strShowGrid = 'Vis gitter';
$strShowHideLeftMenu = 'Vis/skjul venstre menu';
$strShowingBookmark = 'Viser bogmrke';
$strShowingPhp = 'Viser som PHP-kode';
$strShowingRecords = 'Viser poster ';
$strShowingSQL = 'Viser SQL-foresprgsel';
$strShowOpenTables = 'Vis bne tabeller';
$strShowPHPInfo = 'Vis PHP-information';
$strShow = 'Vis';
$strShowSlaveHosts = 'Vis slavevrter';
$strShowSlaveStatus = 'Vis slavestatus';
$strShowStatusBinlog_cache_disk_useDescr = 'Antal transaktioner der brugte det midlertidige binre log mellemlager, men overskred vrdien for binlog_cache_size og brugte en midlertidig fil til at gemme statements fra transaktionen.';
$strShowStatusBinlog_cache_useDescr = 'Antal transaktioner der brugte det midlertidige binre log mellemlager.';
$strShowStatusCreated_tmp_disk_tablesDescr = 'Antal midlertidige tabeller p disken oprettet automatisk af serveren under udfrelse af statements. Hvis Created_tmp_disk_tables er stor, skal du overveje at forge tmp_table_size vrdien for at gre midlertidige tabeller hukommelses-baserede i stedet for disk-baserede.';
$strShowStatusCreated_tmp_filesDescr = 'Hvor mange midlertidige filer mysqld har oprettet.';
$strShowStatusCreated_tmp_tablesDescr = 'Antal i-hukommelsen midlertidige tabeller oprettet automatisk af serveren under udfrelse af statements.';
$strShowStatusDelayed_errorsDescr = 'Antal rkker skrevet med INSERT DELAYED (forsinket indsttelse) under hvilke der opstod fejl (sandsynligvis dublerede ngler).';
$strShowStatusDelayed_insert_threadsDescr = 'Antallet af INSERT DELAYED handler-trde i brug. Hver forskellig tabel hvorp en bruger INSERT DELAYED fr sin egen trd.';
$strShowStatusDelayed_writesDescr = 'Antallet af INSERT DELAYED rkker skrevet.';
$strShowStatusFlush_commandsDescr = 'Antallet af udfrte FLUSH statements.';
$strShowStatusHandler_commitDescr = 'Antallet af interne COMMIT statements.';
$strShowStatusHandler_deleteDescr = 'Antallet af gange en rkke blev slettet fra en tabel.';
$strShowStatusHandler_discoverDescr = 'MySQL serveren kan sprge en NDB Cluster storage engine om den kender til en tabel med et givent navn. Dette kaldes opdagelse. Handler_discover indikerer antallet af gange tabeller er blevet opdaget.';
$strShowStatusHandler_read_firstDescr = 'Antallet af gange frste indlg blev lst fra et indeks. Hvis denne er hj, antyder det at serveren laver mange fulde indeks scans; for eksempel, SELECT col1 FROM foo, antagende at col1 er indekseret.';
$strShowStatusHandler_read_keyDescr = 'Antallet af anmodninger om at lse en rkke baseret p en ngle. Hvis denne er hj, er det en god indikation af at dine foresprgsler og tabeller er ordentligt indekserede.';
$strShowStatusHandler_read_nextDescr = 'Antallet af anmodninger om at lse nste rkke i ngleorden. Denne forges hvis du foresprger p en indekskolonne med en range-begrnsning eller hvis du udfrer et indeks scan.';
$strShowStatusHandler_read_prevDescr = 'Antallet af anmodninger om at lse foregende rkke i ngleorden. Denne lsemetode bruges hovedsageligt til at optimere ORDER BY ... DESC.';
$strShowStatusHandler_read_rndDescr = 'Antallet af anmodninger om at lse en rkke baseret p en fast position. Denne er hj hvis du laver mange foresprgsler der krver sortering af resultatet. Du har sandsynligvis mange foresprgsler der forlanger at MySQL scanner hele tabeller eller du har joins der ikke bruger ngler ordentligt.';
$strShowStatusHandler_read_rnd_nextDescr = 'Antallet af anmodninger om lsning af nste rkke i datafilen. Denne er hj hvis du laver mange tabelscanninger. Generelt antyder dette at dine tabeller enten ikke er ordentligt indekserede eller at dine foresprgsler ikke er skrevet til at drage fordel af de indeks du har.';
$strShowStatusHandler_rollbackDescr = 'Antallet af interne ROLLBACK statements.';
$strShowStatusHandler_updateDescr = 'Antallet af anmodninger om at opdatere en rkke i en tabel.';
$strShowStatusHandler_writeDescr = 'Antallet af anmodninger om at indstte en rkke i en tabel.';
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'Antallet af sider der indeholder data (beskidte eller rene).';
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'Antallet af skaldt beskidte sider.';
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'Antallet af buffer pool sider der er anmodet om at skulle flushes.';
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'Antallet af frie sider.';
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'Antallet af eksklusivt lste (latched) sider i InnoDB buffer pool. Dette er sider der i jeblikket lses eller skrives eller som ikke kan flushes eller fjernes af andre rsager.';
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'Antallet af travle sider fordi de er blevet allokeret til administrativ overhead s som rkkelse eller det adaptive hash indeks. Denne vrdi kan ogs beregnes som  Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total strrelse p buffer pool, i sider.';
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'Antallet af "tilfldige" read-aheads InnoDB initierede. Dette sker nr en foresprgsel skal scanne en strre del af en tabel men i tilfldig rkkeflge.';
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'Antallet af sekventielle read-aheads InnoDB initierede. Dette sker nr InnoDB laver en sekventiel fuld tabelscanning.';
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'Antallet af logiske read anmodninger InnoDB har lavet.';
$strShowStatusInnodb_buffer_pool_readsDescr = 'Antallet af logiske reads som InnoDB ikke kunne tilfredsstille fra buffer pool og mtte lave en enkelt-side read.';
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normalt sker skrivninger til InnoDB buffer poolen i baggrunden. Men, hvis der er brug for at lse eller oprette en side og der ikke er nogen rene sider tilgngelige, er det ndvendigt at vente p at der bliver flushet sider frst. Denne tller tller hvor mange gange det er sket. Hvis buffer pool strrelsen er sat ordentligt, skulle denne vrdi vre lille.';
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'Antallet af skrivninger til InnoDB buffer poolen.';
$strShowStatusInnodb_data_fsyncsDescr = 'Antallet af fsync() operationer indtil nu.';
$strShowStatusInnodb_data_pending_fsyncsDescr = 'Nuvrende antal ventende fsync() operationer.';
$strShowStatusInnodb_data_pending_readsDescr = 'Nuvrende antal af ventende reads.';
$strShowStatusInnodb_data_pending_writesDescr = 'Nuvrende antal af ventende writes.';
$strShowStatusInnodb_data_readDescr = 'Mngden af data lst indtil nu, i bytes.';
$strShowStatusInnodb_data_readsDescr = 'Det totale antal af data reads.';
$strShowStatusInnodb_data_writesDescr = 'Det totale antal af data writes.';
$strShowStatusInnodb_data_writtenDescr = 'Mngden af data skrevet indtil nu, i bytes.';
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'Antallet af doublewrite skrivninger der er udfrt og antallet af sider der er blevet skrevet til dette forml.';
$strShowStatusInnodb_dblwr_writesDescr = 'Antallet af doublewrite skrivninger der er udfrt og antallet af sider der er blevet skrevet til dette forml.';
$strShowStatusInnodb_log_waitsDescr = 'Antallet af waits vi har haft fordi log buffer var for lille og vi skulle vente p at den blev flushed fr vi kunne fortstte.';
$strShowStatusInnodb_log_write_requestsDescr = 'Antallet af log write anmodninger.';
$strShowStatusInnodb_log_writesDescr = 'Antallet af fysiske skrivninger til log filen.';
$strShowStatusInnodb_os_log_fsyncsDescr = 'Antallet af fsyncs skrivninger lavet til log filen.';
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'Antallet af ventende log fil fsyncs.';
$strShowStatusInnodb_os_log_pending_writesDescr = 'Ventende log fil skrivninger.';
$strShowStatusInnodb_os_log_writtenDescr = 'Antallet af bytes skrevet til log filen.';
$strShowStatusInnodb_pages_createdDescr = 'Antallet af sider oprettet.';
$strShowStatusInnodb_page_sizeDescr = 'Den indkompilerede InnoDB sidestrrelse (standard 16KB). Mange vrdier tlles i sider; sidestrrelsen gr at man let kan omregne dem til bytes.';
$strShowStatusInnodb_pages_readDescr = 'Antallet af sider lst.';
$strShowStatusInnodb_pages_writtenDescr = 'Antallet af sider skrevet.';
$strShowStatusInnodb_row_lock_current_waitsDescr = 'Antallet af rkkelse der ventes p i jeblikket.';
$strShowStatusInnodb_row_lock_time_avgDescr = 'Gennemsnitstiden for at f en rkkels, i millisekunder.';
$strShowStatusInnodb_row_lock_timeDescr = 'Total tid brugt p at hente rkkelse, i millisekunder.';
$strShowStatusInnodb_row_lock_time_maxDescr = 'Maksimale tid for at hente en rkkels, i millisekunder.';
$strShowStatusInnodb_row_lock_waitsDescr = 'Antallet af gange der skulle ventes p en rkkels.';
$strShowStatusInnodb_rows_deletedDescr = 'Antallet af rkker slettet fra InnoDB tabeller.';
$strShowStatusInnodb_rows_insertedDescr = 'Antallet af rkker indsat i InnoDB tabeller.';
$strShowStatusInnodb_rows_readDescr = 'Antallet af rkker lst fra InnoDB tables.';
$strShowStatusInnodb_rows_updatedDescr = 'Antallet af rkker opdateret i InnoDB tabeller.';
$strShowStatusKey_blocks_not_flushedDescr = 'Antallet af ngleblokeringer i nglemellemlageret der har ndret sig men endnu ikke er blevet flushet til disk. Det hed tidligere Not_flushed_key_blocks.';
$strShowStatusKey_blocks_unusedDescr = 'Antallet af ubrugte blokke i nglemellemlageret. Du kan bruge denne vrdi til at fastsl hvor meget af nglemellemlagere der er i brug.';
$strShowStatusKey_blocks_usedDescr = 'Antallet af brugte blokke i nglemellemlageret. Denne vrdi er et hjvande-mrke der indikerer det maksimale antal blokke der p noget tidspunkt har vret i brug p en gang.';
$strShowStatusKey_read_requestsDescr = 'Antallet af anmodninger om at lse en ngleblok fra mellemlageret.';
$strShowStatusKey_readsDescr = 'Antallet af fysiske lsninger af en ngleblok fra disk. Hvis Key_reads er stor, er din key_buffer_size vrdi sandsynligvis for lille. Mellemlager miss raten kan beregnes som  Key_reads/Key_read_requests.';
$strShowStatusKey_write_requestsDescr = 'Antallet af anmodninger om at skrive en ngleblok til mellemlageret.';
$strShowStatusKey_writesDescr = 'Antallet af fysiske skrivninger af en ngleblok til disk.';
$strShowStatusLast_query_costDescr = 'Totale omkostninger for den seneste kompilerede foresprgsel som beregnet af foresprgsels-optimeringsrutinen. Brugbart til at sammenligne omkostninger p forskellige foresprgselsplaner for den samme foresprgsel. En standardvrdi p 0 betyder at der ikke er kompileret nogen foresprgsler endnu.';
$strShowStatusNot_flushed_delayed_rowsDescr = 'Antallet af rkker der venter p at blive skrevet i INSERT DELAY ker.';
$strShowStatusOpened_tablesDescr = 'Antallet af tabeller der er blevet bnet. Hvis bnede tabeller er stor, er dit tabelmellemlager sandsynligvis for lille.';
$strShowStatusOpen_filesDescr = 'Antallet af filer der er bne.';
$strShowStatusOpen_streamsDescr = 'Antallet af streams der er bne (bruges hovedsageligt til logning).';
$strShowStatusOpen_tablesDescr = 'Antallet af tabeller der er bne.';
$strShowStatusQcache_free_blocksDescr = 'Antallet af frie hukommelsesblokke i foresprgsels-mellemlageret.';
$strShowStatusQcache_free_memoryDescr = 'Mngden af fri hukommelse til foresprgselsmellemlageret.';
$strShowStatusQcache_hitsDescr = 'Antallet af mellemlager hits.';
$strShowStatusQcache_insertsDescr = 'Antallet af foresprgsler tilfjet til mellemlageret.';
$strShowStatusQcache_lowmem_prunesDescr = 'Antallet af foresprgsler der er blevet fjernet fra mellemlageret for at rydde hukommelse til mellemlagring af nye foresprgsler. Denne information kan hjlpe dig med at tune foresprgselsmellemlagerets strrelse. Foresprgselsmellemlageret bruger en mindst nyligt brugt (LRU) strategi til at afgre hvilke foresprgsler der skal fjernes fra mellemlageret.';
$strShowStatusQcache_not_cachedDescr = 'Antallet af ikke-mellemlagrede foresprgsler (ikke mulige at mellemlagre eller ikke mellemlagret grundet query_cache_type indstillingen).';
$strShowStatusQcache_queries_in_cacheDescr = 'Antallet af foresprgsler registreret i mellemlageret.';
$strShowStatusQcache_total_blocksDescr = 'Totalt antal blokke i foresprgsels-mellemlageret.';
$strShowStatusReset = 'Nulstil';
$strShowStatusRpl_statusDescr = 'Status p failsafe replikering (endnu ikke implementeret).';
$strShowStatusSelect_full_joinDescr = 'Antallet af joins der ikke bruger indeks. Hvis denne vrdi ikke er 0, br du nje tjekke indeksene p dine tabeller.';
$strShowStatusSelect_full_range_joinDescr = 'Antallet af joins der brugte en range sgning p en reference tabel.';
$strShowStatusSelect_range_checkDescr = 'Antallet af joins uden ngler der tjekker for nglebrug efter hver rkke. (Hvis denne ikke er 0, br du nje tjekke indeks p dine tabeller.)';
$strShowStatusSelect_rangeDescr = 'Antallet af joins der brugte ranges p den frste tabel. (Normalt ikke kritisk selvom tallet er stort.)';
$strShowStatusSelect_scanDescr = 'Antallet af joins som lavede en fuld scan af den frste tabel.';
$strShowStatusSlave_open_temp_tablesDescr = 'Antallet af midlertidige tabeller i jeblikket bne af SQL trden.';
$strShowStatusSlave_retried_transactionsDescr = 'Totalt (siden opstart) antal gange replikeringsslave SQL trden har gen-forsgt transaktioner.';
$strShowStatusSlave_runningDescr = 'Dette er TIL hvis denne server er en slave der er forbundet til en master.';
$strShowStatusSlow_launch_threadsDescr = 'Antallet af trde der har taget mere end slow_launch_time sekunder at oprette.';
$strShowStatusSlow_queriesDescr = 'Antallet af foresprgsler der har taget mere end long_query_time sekunder.';
$strShowStatusSort_merge_passesDescr = 'Antallet af sammenlgningskrsler sorteringsalgoritmen skulle lave. Hvis denne vrdi er hj, br du overveje at forge vrdien af  sort_buffer_size systemvariablen.';
$strShowStatusSort_rangeDescr = 'Antallet af sorteringer lavet med ranges.';
$strShowStatusSort_rowsDescr = 'Antallet af sorterede rkker.';
$strShowStatusSort_scanDescr = 'Antallet af sorteringer udfrt ved scanning af tabellen.';
$strShowStatusTable_locks_immediateDescr = 'Antallet af gange en tabells blev givet jeblikkeligt.';
$strShowStatusTable_locks_waitedDescr = 'Antallet af gange en tabells ikke kunne fs jeblikkeligt og en wait var ndvendig. Hvis denne er hj, og du har ydelsesproblemer, br du frst optimere dine foresprgsler, og derefter enten opdele din tabel eller tabeller, eller bruge replikering.';
$strShowStatusThreads_cachedDescr = 'Antallet af trde i trd-mellemlageret. Mellemlager-hitraten kan udregnes som Threads_created/Forbindelser. Hvis denne vrdi er rd br du forge din thread_cache_size.';
$strShowStatusThreads_connectedDescr = 'Antallet af i jeblikket bne forbindelser.';
$strShowStatusThreads_createdDescr = 'Antallet af trde oprettet til at hndtere forbindelser. Hvis Threads_created er stor, kan du vlge at forge thread_cache_size vrdien. (Normalt giver dette ingen nvnevrdig ydelsesforbedring hvis du har god trd-implementering.)';
$strShowStatusThreads_runningDescr = 'Antallet af trde der ikke sover.';
$strShowTableDimension = 'Vis tabellernes dimensioner';
$strShowTables = 'Vis tabeller';
$strShowThisQuery = ' Vis foresprgslen her igen ';
$strSimplifiedChinese = 'Simplificeret Kinesisk';
$strSingly = '(enkeltvis)';
$strSize = 'Strrelse';
$strSkipQueries = 'Antal poster (queries) der skal springes over fra start';
$strSlovak = 'Slovakisk';
$strSlovenian = 'Slovensk';
$strSmallBigAll = 'Sm/store alle';
$strSnapToGrid = 'Snap til gitter';
$strSocketProblem = '(eller den lokale MySQL servers socket er ikke korrekt konfigureret)';
$strSortByKey = 'Sorteringsngle';
$strSorting = 'Sortering';
$strSort = 'Sorter';
$strSpaceUsage = 'Pladsforbrug';
$strSpanish = 'Spansk';
$strSplitWordsWithSpace = 'Ord adskilles af mellemrums-karakter (" ").';
$strSQLCompatibility = 'SQL-kompatibilitetsmodus';
$strSQLExportType = 'Eksporttype';
$strSQLImportOptions = 'SQL-indstillinger';
$strSQLOptions = 'SQL-indstillinger';
$strSQLParserBugMessage = 'Det er muligt at du har fundet en fejl i SQL-parseren. Undersg venligst din foresprgsel nje, og check at anfrselstegn er rigtige og ikke giver konflikter. Andre fejlrsager kan vre at du uploader en fil med binr udenfor et lukket tekstomrde. Du kan ogs prve din foresprgsel i MySQL kommandolinje-interfacet. MySQL-serverens fejlmelding der flger herunder, hvis der er nogen, kan ogs hjlpe dig med at finde problemet. Hvis du stadig har probemer eller hvis parseren fejler hvor kommandolinjeinterfacet lykkes, reducer din SQL-foresprgselsinput til den ene foresprgsel der forrsager problemet, og indsend en fejlrapport med datablokken i KLIP-sektionen herunder:';
$strSQLParserUserError = 'Der ser ud til at vre en fejl i din SQL-foresprgsel. MySQL-serverens fejlmelding der flger herunder, hvis der er nogen, kan ogs hjlpe dig med at finde problemet.';
$strSQLQuery = 'SQL-foresprgsel';
$strSQLResult = 'SQL-resultat';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Ugyldig identifikator';
$strSQPBugUnclosedQuote = 'Ikke-lukket quote';
$strSQPBugUnknownPunctuation = 'Ukendt tegnstnings-streng';
$strStandInStructureForView = 'Stand-in-struktur for visning';
$strStatCheckTime = 'Sidste check';
$strStatCreateTime = 'Oprettelse';
$strStatement = 'Erklringer';
$strStatisticsOverrun = 'P en travl server er der risiko for at bytetllerne lber over, s disse statistikker som rapporteret af MySQL-serveren kan vre forkerte.';
$strStatUpdateTime = 'Sidste opdatering';
$strStatus = 'Status';
$strStorageEngine = 'Datalager';
$strStorageEngines = 'Datalagre';
$strStrucCSV = 'CSV-data';
$strStrucData = 'Struktur og data';
$strStrucExcelCSV = 'CSV til MS Excel-data';
$strStrucNativeExcel = 'Fdte MS Excel-data';
$strStrucNativeExcelOptions = 'Fdte Excel eksportindstillinger';
$strStrucOnly = 'Kun strukturen';
$strStructPropose = 'Foresl tabelstruktur';
$strStructureForView = 'Struktur for visning';
$strStructure = 'Struktur';
$strSubmit = 'Send';
$strSuccess = 'Din SQL-foresprgsel blev udfrt korrekt';
$strSum = 'Sum';
$strSwedish = 'Svensk';
$strSwitchToDatabase = 'Skift til den kopierede database';
$strSwitchToTable = 'Skift til den kopierede tabel';

$strTableAlreadyExists = 'Table %s already exists!';
$strTableComments = 'Tabel kommentarer';
$strTableEmpty = 'Intet tabelnavn!';
$strTableHasBeenDropped = 'Tabel %s er slettet';
$strTableHasBeenEmptied = 'Tabel %s er tmt';
$strTableHasBeenFlushed = 'Tabel %s er blevet flushet';
$strTableIsEmpty = 'Tabel ser ud til at vre tom!';
$strTableMaintenance = 'Tabelvedligeholdelse';
$strTableName = 'Tabelnavn';
$strTableOfContents = 'Indholdsfortegnelse';
$strTableOptions = 'Tabel-indstillinger';
$strTables = '%s tabel(ler)';
$strTableStructure = 'Struktur-dump for tabellen';
$strTable = 'Tabel';
$strTakeIt = 'Vlg dette';
$strTblPrivileges = 'Tabel-specifikke privilegier';
$strTempData = 'Midlertidige data';
$strTextAreaLength = ' P grund af feltets lngde,<br /> kan det muligvis ikke ndres ';
$strThai = 'Thai';
$strThemeDefaultNotFound = 'Standardtema %s ikke fundet!';
$strThemeNoPreviewAvailable = 'Intet billede til rdighed.';
$strThemeNotFound = 'Tema %s ikke fundet!';
$strThemeNoValidImgPath = 'Ingen gyldig billedsti for tema %s fundet!';
$strThemePathNotFound = 'Sti til tema ikke fundet for tema %s!';
$strTheme = 'Tema / Layout';
$strThisHost = 'Denne Host';
$strThreads = 'Trde';
$strThreadSuccessfullyKilled = 'Trd %s blev stoppet.';
$strTimeoutInfo = 'Foregende import timede ud, efter genindsendelse vil fortstte fra position %d.';
$strTimeoutNothingParsed = 'Desvrre blev der ikke parset nogen data ved sidste krsel, dette betyder normalt at phpMyAdmin ikke vil vre i stand til at gennemfre importen med mindre du forger PHP-tidsbegrnsningerne.';
$strTimeoutPassed = 'Script timeout net, hvis du vil afslutte importen, indsend venligst samme fil igen og importen vil fortstte hvor den slap.';
$strTime = 'Tid';
$strToFromPage = 'til/fra side';
$strToggleScratchboard = 'tegnebrt til/fra';
$strToggleSmallBig = 'Skift mellem sm/store';
$strToSelectRelation = 'For at vlge relation, klik :';
$strTotal = 'total';
$strTotalUC = 'Total';
$strTraditionalChinese = 'Traditionelt Kinesisk';
$strTraditionalSpanish = 'Traditionelt Spansk';
$strTraffic = 'Trafik';
$strTransactionCoordinator = 'Transaktionskoordinator';
$strTransformation_application_octetstream__download = 'Viser et link til at downloade et felts binre data. Frste indstilling er filnavnet p den binre fil. Anden indstilling er et muligt feltnavn fra en tabelrkke indeholdende filnavnet. Hvis du bruger anden indstilling, skal feltet i den frste indstilling vre sat til en tom streng.';
$strTransformation_application_octetstream__hex = 'Viser hexadecimal udgave af data. Valgfrit frsteparameter angiver hvor meget plads der tilfjes (standard er 2 nibbles).';
$strTransformation_image_jpeg__inline = 'Viser et klikbart minibillede; indstillinger: bredde,hjde i pixel. Det originale perspektiv bevares.';
$strTransformation_image_jpeg__link = 'Viser et link til dette billede (f.eks. direkte blob-download).';
$strTransformation_image_png__inline = 'Se under image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Viser et TIME, TIMESTAMP, DATETIME eller numerisk unix tidsstempel-felt som formatteret dato. Den frste indstilling er offset (i timer) som vil blive lagt til tidsstemplet (Standard: 0). Brug anden indstilling til at angive en anderledes dato-/tidsformatstreng. Tredje indstilling faststter om du vil se lokal dato eller UTC (brug "local" eller "utc" strenge) til dette. Ud fra dette har datoformatet forskellig vrdi - for "local" se dokumentationen for PHP\'s strftime() funktion og for "utc" sker det ved brug af gmdate() funktionen.';
$strTransformation_text_plain__external = 'KUN LINUX: Starter en ekstern applikation og fder feltdata via standard input. Returnerer standardoutputtet for applikationen. Standard er Tidy, for korrekt udskrivning af HTML-kode. Af sikkerhedsrsager er du ndt til manuelt at redigere filen libraries/transformations/text_plain__external.inc.php og indstte de vrktjer du vil tillade krsel af. Frste indstilling er s nummeret p det program du vil bruge og den anden indstilling er parametrene for dette program. Tredie parameter vil, hvis sat til 1, konvertere outputtet vha. htmlspecialchars() (Standard er 1). Et fjerde parameter vil, hvis sat til 1, stte et NOWRAP om cellens indhold s hele outputtet bliver vist uden omformattering (Standard 1)';
$strTransformation_text_plain__formatted = 'Bevarer original formattering af feltet. Der laves ikke nogen Escaping.';
$strTransformation_text_plain__imagelink = 'Viser et billede og et link, feltet indeholder filnavnet; frste indstilling er et prfiks som "http://domain.com/", anden indstilling er bredde i pixel, tredie er hjden.';
$strTransformation_text_plain__link = 'Viser et link, feltet indeholder filnavnet; frste indstilling er et prfiks som "http://domain.com/", anden indstilling er en titel p linket.';
$strTransformation_text_plain__sql = 'Formatterer tekst som SQL-foresprgsel med syntaks farvemarkering.';
$strTransformation_text_plain__substr = 'Viser en del af en streng. Frste parameter er antal tegn der skal springes over fra begyndelsen af en streng (Standard 0). Andet parameter er antal tegn der returneres (Standard indtil enden af strengen). Det tredie parameter definerer hvilke tegn der skal fjes til foran eller efter outputtet nr en substring (understreng) returneres (Standard: "...") .';
$strTruncateQueries = 'Trunkr viste foresprgsler';
$strTurkish = 'Tyrkisk';
$strType = 'Datatype';

$strUkrainian = 'Ukrainsk';
$strUncheckAll = 'Fjern alle mrker';
$strUnicode = 'Unicode';
$strUnique = 'Unik';
$strUnknown = 'ukendt';
$strUnselectAll = 'Fravlg alle';
$strUnsupportedCompressionDetected = 'Du forsgte at indlse en fil med u-understttet komprimering (%s). Understttelse af denne funktion er ikke implementeret eller ikke slet til for din konfiguration.';
$strUpdatePrivMessage = 'Du har opdateret privilegierne for %s.';
$strUpdateProfileMessage = 'Profilen er blevet opdateret.';
$strUpdateQuery = 'Opdater foresprgsel';
$strUpdComTab = 'Se venligst Dokumentationen for oplysninger om hvordan du opdaterer din Column_comments (kolonne-kommentarer) tabel';
$strUpgrade = 'Du burde opdatere til %s %s eller senere.';
$strUploadLimit = 'Du har sandsynligvis forsgt at uploade en for stor fil. Se venligst %sdokumentationen%s for mder hvorp du kan arbejde dig uden om denne begrnsning.';
$strUploadsNotAllowed = 'Fil-uploads er ikke tilladte p denne server.';
$strUsage = 'Benyttelse';
$strUseBackquotes = 'Brug "backquotes" omkring tabeller og felters navne';
$strUsedPhpExtensions = 'Brugte PHP-udvidelser';
$strUseHostTable = 'Brug Host Tabel';
$strUserAlreadyExists = 'Brugeren %s findes i forvejen!';
$strUser = 'Bruger';
$strUserEmpty = 'Intet brugernavn!';
$strUserName = 'Brugernavn';
$strUserNotFound = 'Den valgte bruger blev ikke fundet i privilegietabellen.';
$strUserOverview = 'Brugeroversigt';
$strUsersDeleted = 'De valgte brugere er blevet korrekt slettet.';
$strUsersHavingAccessToDb = 'Brugere med adgang til &quot;%s&quot;';
$strUseTabKey = 'Brug TAB-tasten for at flytte dig fra vrdi til vrdi, eller CTRL+piletasterne til at flytte frit omkring';
$strUseTables = 'Benyt tabeller';
$strUseTextField = 'Brug tekstfelt';
$strUseThisValue = 'Brug denne vrdi';

$strValidateSQL = 'Validr SQL';
$strValidatorError = 'SQL-validatoren kunne ikke initialiseres. Check venligst at du har de ndvendige PHP-udvidelser installeret som beskrevet i %sdokumentationen%s.';
$strValue = 'Vrdi';
$strVar = 'Variabel';
$strVersionInformation = 'Versionsinformation';
$strViewDumpDatabases = 'Vis dump (skema) for databaser';
$strViewDumpDB = 'Vis dump (skema) af database';
$strViewDump = 'Vis dump (skema) over tabel';
$strViewHasBeenDropped = 'Visning %s er blevet droppet';
$strViewMaxExactCount = 'Denne visning har mere end %d rkker. Se venligst %sdokumentationen%s.';
$strView = 'Visning';

$strWebServerUploadDirectoryError = 'Mappen du har sat til upload-arbejde kan ikke findes';
$strWebServerUploadDirectory = 'webserver upload-mappe';
$strWelcome = 'Velkommen til %s';
$strWestEuropean = 'Vesteuropisk';
$strWildcard = 'jokertegn';
$strWindowNotFound = 'Det angivne browservindue kunne ikke opdateres. Mske har du lukket det overliggende vindue eller din browser blokerer for tvr-vindue opdateringer i sikkerhedsindstillingerne';
$strWithChecked = 'Med det markerede:';
$strWriteRequests = 'Write-anmodninger';
$strWrongUser = 'Forkert brugernavn/kodeord. Adgang ngtet.';

$strXMLOptions = 'XML-indstillinger';
$strXML = 'XML';

$strYes = 'Ja';

$strZeroRemovesTheLimit = 'Bemrk: Indstilling af disse vrdier til 0 (nul) fjerner begrnsningen.';
$strZip = '"zippet"';

?>
